from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Security(object):
    """
    Configuration - Security Template Policy API
    
    Implements GET POST DEL PUT methods for SecurityTemplatePolicy endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def generateSecurityTemplateList(self, mode):
        """
        Generate template list
        
        Parameters:
        mode	 (string):	Mode
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security?mode={mode}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createSecurityTemplate(self, policytemplate):
        """
        Create Template
        
        Parameters:
        policytemplate:	Policy template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security"
        response = self.client.apiCall(HttpMethods.POST, endpoint, policytemplate)
        return response


    def getSecurityTemplate(self, policyId):
        """
        Get Template
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/definition/{policyId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSecurityPolicyDeviceList(self):
        """
        Get device list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/devices"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceListById(self, policyId):
        """
        Get device list by Id
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/devices/{policyId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editTemplateWithLenientLock(self, policytemplate, policyId):
        """
        Edit Template
        
        Parameters:
        policytemplate:	Policy template
		policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/staging/{policyId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policytemplate)
        return response


    def generateSecurityPolicySummary(self):
        """
        Generate security policy summary
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/summary"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSecurityTemplatesForDevice(self, deviceModel):
        """
        Get templates that map a device model
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/{deviceModel}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editSecurityTemplate(self, policytemplate, policyId):
        """
        Edit Template
        
        Parameters:
        policytemplate:	Policy template
		policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/{policyId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policytemplate)
        return response


    def deleteSecurityTemplate(self, policyId):
        """
        Delete Template
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/security/{policyId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Interface(object):
    """
    Real-Time Monitoring - Interface API
    
    Implements GET POST DEL PUT methods for Interface endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getInterface(self, vpnId, ifname, af, deviceId):
        """
        Get device interfaces
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getARPStats(self, vpnId, ifname, af, deviceId):
        """
        Get interface ARP statistics
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/arp_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getErrorStats(self, vpnId, ifname, af, deviceId):
        """
        Get interface error stats
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/error_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getV6Stats(self, vpnId, ifname, af, deviceId):
        """
        Get interface IPv6 stats
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/ipv6Stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPktSizes(self, vpnId, ifname, af, deviceId):
        """
        Get interface packet size
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/pkt_size?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPortStats(self, vpnId, ifname, af, deviceId):
        """
        Get interface port stats
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/port_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getQosStats(self, vpnId, ifname, af, deviceId):
        """
        Get interface QOS stats
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/qosStats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getQueueStats(self, vpnId, ifname, af, deviceId):
        """
        Get interface queue stats
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/queue_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceSerialInterface(self, vpnId, ifname, af, deviceId):
        """
        Get serial interface
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/serial?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStats(self, vpnId, ifname, af, deviceId):
        """
        Get interface stats
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncedInterface(self, vpnId, ifname, af, deviceId):
        """
        Get device interfaces synchronously
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	IF Name
		af  	        (string):	AF Type
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/synced?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def trustsec(self, deviceId):
        """
        Get policy filter memory usage from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/trustsec?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInterfaceVPN(self, deviceId):
        """
        Get device interfaces per VPN
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/interface/vpn?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class OSPF(object):
    """
    Real-Time Monitoring - OSPF API
    
    Implements GET POST DEL PUT methods for OSPF endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getDbList(self, deviceId):
        """
        Get OSPF database list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/database?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDbExt(self, deviceId):
        """
        Get OSPF external database list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/databaseexternal?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDbSummary(self, deviceId):
        """
        Get OSPF database summary list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/databasesummary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInterfaces(self, deviceId):
        """
        Get OSPF interface list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/interface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNeighbors(self, deviceId):
        """
        Get OSPF neighbor list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/neighbor?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getProcess(self, deviceId):
        """
        Get OSPF process list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/process?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRoutes(self, deviceId):
        """
        Get OSPF route list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/routes?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getV3Interface(self, deviceId):
        """
        Get OSPF v3 interface list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/v3interface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getV3Neighbors(self, deviceId):
        """
        Get OSPF v3 neighbor list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ospf/v3neighbor?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Trustsec(object):
    """
    Real-Time Monitoring - Trustsec API
    
    Implements GET POST DEL PUT methods for Trustsec endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getCtsPac(self, deviceId):
        """
        get Cisco TrustSec PAC information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ctsPac?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEnvData(self, deviceId):
        """
        get Cisco TrustSec Environment Data information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/environmentData?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRadiusServer(self, deviceId):
        """
        get Cisco TrustSec Environment Data Radius Server list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/environmentData/radiusServer?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRBCounters(self, deviceId):
        """
        get Cisco TrustSec Role Based Counters information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/roleBasedCounters?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRBv6Counters(self, deviceId):
        """
        get Cisco TrustSec Role Based Ipv6 Counters information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/roleBasedIpv6Counters?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRBv6Perms(self, deviceId):
        """
        get Cisco TrustSec Role Based ipv6 Permissions information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/roleBasedIpv6Permissions?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRBPermissions(self, deviceId):
        """
        get Cisco TrustSec Role Based Permissions information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/roleBasedPermissions?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRBSgtMap(self, deviceId):
        """
        get Cisco TrustSec Role Based SGT Map information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/roleBasedSgtMap?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSxpConnections(self, deviceId):
        """
        get Cisco TrustSec SXP Connections information from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/sxpConnections?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Flow(object):
    """
    Monitoring - Cflowd Flows API
    
    Implements GET POST DEL PUT methods for CflowdFlows endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getCflowdDPIDeviceFieldJSON(self, isDeviceDashBoard):
        """
        Get Cflowd DPI query field JSON
        
        Parameters:
        isDeviceDashBoard	 (boolean):	Flag whether it is device dashboard request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/application/fields?isDeviceDashBoard={isDeviceDashBoard}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCollectorList(self, deviceId):
        """
        Get cflowd collector list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/collector?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDPIFieldJSON(self, isDeviceDashBoard):
        """
        Get CflowdvDPI query field JSON
        
        Parameters:
        isDeviceDashBoard	 (boolean):	Flag whether it is device dashboard request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/device/fields?isDeviceDashBoard={isDeviceDashBoard}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFlows(self, vpnId, src, dest, deviceId):
        """
        Get list of cflowd flows from device
        
        Parameters:
        vpnId	        (string):	VPN Id
		src	            (string):	Source IP
		dest	        (string):	Destination IP
		deviceId	    (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/flows?vpn-id={vpnId}&src-ip={src}&dest-ip={dest}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFlowsCount(self, vpnId, src, dest, deviceId):
        """
        Get cflowd flow count from device
        
        Parameters:
        vpnId	        (string):	VPN Id
		src	            (string):	Source IP
		dest	        (string):	Destination IP
		deviceId	    (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/flows-count?vpn-id={vpnId}&src-ip={src}&dest-ip={dest}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFnFCacheStats(self, deviceId):
        """
        Get FnF cache stats from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/fnf/cache-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFnFExportClientStats(self, deviceId):
        """
        Get FnF export client stats from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/fnf/export-client-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFnFExportStats(self, deviceId):
        """
        Get FnF export stats from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/fnf/export-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFnf(self, deviceId):
        """
        Get FnF from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/fnf/flow-monitor?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFnFMonitorStats(self, deviceId):
        """
        Get FnF monitor stats from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/fnf/monitor-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatistics(self, deviceId):
        """
        Get cflowd statistics from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/statistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTemplate(self, deviceId):
        """
        Get cflowd template from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cflowd/template?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Cluster(object):
    """
    Cluster Management API
    
    Implements GET POST DEL PUT methods for ClusterManagement endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def checkIfClusterLocked(self):
        """
        Check whether cluster is locked
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/clusterLocked"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getClusterWorkflowVersion(self):
        """
        List vManages in the cluster
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/clusterworkflow/version"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def configureVmanage(self, vmanageConfig):
        """
        Configure vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        vmanageConfig:	vManage server config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/configure"
        response = self.client.apiCall(HttpMethods.POST, endpoint, vmanageConfig)
        return response


    def getConnectedDevices(self, vmanageIP):
        """
        Get connected device for vManage
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        vmanageIP	 (string):	vManage IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/connectedDevices/{vmanageIP}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def healthDetails(self):
        """
        Get cluster health check details
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/health/details"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def healthStatusInfo(self):
        """
        Get cluster health check details
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/health/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def healthSummary(self, isCached):
        """
        Get cluster health check summary
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        isCached	 (boolean):	Flag to enable cached result
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/health/summary?isCached={isCached}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConfiguredIPList(self, vmanageID):
        """
        Get configured IP addresses
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        vmanageID	 (string):	vManage Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/iplist/{vmanageID}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def isClusterReady(self):
        """
        Is cluster ready
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/isready"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listVmanages(self):
        """
        List vManages in the cluster
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/list"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def nodeProperties(self):
        """
        Get properties of vManage being added to  cluster
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/nodeProperties"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def removeVmanage(self, vmanageInfo):
        """
        Remove vManage from cluster
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        vmanageInfo:	vManage server info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/remove"
        response = self.client.apiCall(HttpMethods.POST, endpoint, vmanageInfo)
        return response


    def performReplicationAndRebalanceOfKafkaPartitions(self):
        """
        Initiate replication and rebalance of kafka topics
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/replicateAndRebalance"
        response = self.client.apiCall(HttpMethods.PUT, endpoint)
        return response


    def editVmanage(self, clusterConfig):
        """
        Update vManage cluster info
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        clusterConfig:	vManage cluster config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/setup"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, clusterConfig)
        return response


    def addVmanage(self, clusterConfig):
        """
        Add vManage to cluster
        
        Parameters:
        clusterConfig:	vManage cluster config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/setup"
        response = self.client.apiCall(HttpMethods.POST, endpoint, clusterConfig)
        return response


    def getTenancyMode(self):
        """
        Get vManage tenancy mode
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/tenancy/mode"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setTenancyMode(self, tenancySetting):
        """
        Update vManage tenancy mode
        
        Parameters:
        tenancySetting:	Tenancy mode setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/tenancy/mode"
        response = self.client.apiCall(HttpMethods.POST, endpoint, tenancySetting)
        return response


    def getTenantsList(self):
        """
        Get tenant list
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/tenantList"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def addOrUpdateUserCredentials(self, creds):
        """
        Add or update user credentials for cluster operations
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        creds:	User credential
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/userCreds"
        response = self.client.apiCall(HttpMethods.POST, endpoint, creds)
        return response


    def getVManageDetails(self, vmanageIP):
        """
        Get vManage detail
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        vmanageIP	 (string):	vManage IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/vManage/details/{vmanageIP}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConnectedDevicesPerTenant(self, tenantId, vmanageIP):
        """
        Get connected device for vManage for a tenant
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        tenantId	 (string):	Tenant Id
		vmanageIP	 (string):	vManage IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/clusterManagement/{tenantId}/connectedDevices/{vmanageIP}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DeviceStatisticsDetails(object):
    """
    Monitoring - Device Statistics Details API
    
    Implements GET POST DEL PUT methods for DeviceStatisticsDetails endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getStatisticsType(self):
        """
        Get statistics types
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/statistics"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getActiveAlarms(self, scrollId, startDate, endDate, count, timeZone):
        """
        Get active alarms
        
        Parameters:
        scrollId	 (string):	SrollId
		startDate	 (string):	Start date
		endDate	 (string):	End date
		count	 (integer):	count
		timeZone	 (string):	Time zone
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/statistics/alarm/active?scrollId={scrollId}&startDate={startDate}&endDate={endDate}&count={count}&timeZone={timeZone}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsData(self, state_data_type, scrollId, startDate, endDate, count, timeZone):
        """
        Get device statistics data
        
        Parameters:
        state_data_type	 (string):	State data type
		scrollId	 (string):	Scroll Id
		startDate	 (string):	Start date
		endDate	 (string):	End date
		Parameter Description
		timeZone	 (string):	Time zone
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/statistics/{state_data_type}?scrollId={scrollId}&startDate={startDate}&endDate={endDate}&count={count}&timeZone={timeZone}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountWithStateDataType(self, state_data_type, startDate, endDate, timeZone):
        """
        Get response count of a query
        
        Parameters:
        state_data_type	 (string):	State data type
		startDate	 (string):	Start date
		endDate	 (string):	End date
		timeZone	 (string):	Time zone
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/statistics/{state_data_type}/doccount?startDate={startDate}&endDate={endDate}&timeZone={timeZone}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getFieldsByType(self, state_data_type):
        """
        Get statistics fields and types
        
        Parameters:
        state_data_type	 (string):	State data type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/data/device/statistics/{state_data_type}/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Sdavc(object):
    """
    SD AVC Cloud Connector API
    
    Implements GET POST DEL PUT methods for SDAVCCloudConnector endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getCloudConnector(self):
        """
        Get SD_AVC Cloud Connector Config
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/cloudconnector"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def disableCloudConnector(self, payload):
        """
        Disable SD_AVC Cloud Connector
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/cloudconnector"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, payload)
        return response


    def enableCloudConnector(self, payload):
        """
        Enable SD_AVC Cloud Connector
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/cloudconnector"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getCloudConnectorStatus(self):
        """
        Get SD_AVC Cloud Connector Status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sdavc/cloudconnector/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class PIM(object):
    """
    Real-Time Monitoring - PIM API
    
    Implements GET POST DEL PUT methods for PIM endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getInterfaceList(self, deviceId):
        """
        Get PIM interface list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/pim/interface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getNeighborList(self, deviceId):
        """
        Get PIM neighbor list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/pim/neighbor?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRpMappingList(self, deviceId):
        """
        Get PIM Rp-mapping list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/pim/rp-mapping?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsList(self, deviceId):
        """
        Get PIM statistics list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/pim/statistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPPPInterfaceList(self, deviceId):
        """
        Get PPP interface list from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ppp/interface?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Onboard(object):
    """
    MDP - Onboarding API
    
    Implements GET POST DEL PUT methods for Onboarding endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def onboardMDP(self, onboard):
        """
        Start MDP onboarding operation
        
        Parameters:
        onboard:	Onboard
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/onboard"
        response = self.client.apiCall(HttpMethods.POST, endpoint, onboard)
        return response


    def getOnboardStatus(self):
        """
        Get MDP onboarding status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/onboard/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateOnboardingPayload(self, onboard, nmsId):
        """
        update MDP onboarding document
        
        Parameters:
        onboard:	Onboard
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/onboard/{nmsId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, onboard)
        return response


